;             2000 Access I/O Processor Load and Dump Command File.
;
;
; This command file is invoked to run as a separate simulator instance to load
; a new 2000 Access I/O Processor operating system into the IOP via a cross-load
; from the System Processor and then to dump it back to the SP to be stored to
; magnetic tape.  It is invoked by the "tsb-iopgen.sim" command file, as
; follows:
;
;    hp2100 iopdump.inc <cpu-model> <cpu-series>
;
; ...where <cpu-model> is the specific CPU model to simulate (2100, 21MX, or
; 21MX-E), and <cpu-series> is the general CPU type (2100 or 21MX).  It is never
; invoked directly by the user.


; Capture the I/O Processor load and dump log.

set -N CONSOLE LOG=iopdump-%2.log


; Configure the I/O Processor.

do iopconfig.inc %1


; Connect the Processor Interconnect cables to the IOP.
;
; The code number here ("4020") is significant only in that the SP instance
; must use the same code number to ensure interprocessor communication.

attach -I IPL 4020


; Start the binary loader, which is used as the cross loader via the IPL device.
; The loader starts with a CLC 0,C that must execute before the SP begins to
; send data.  So we load the bootstrap into memory and then step through until
; we reach the SFS in the input loop.
;
; In hardware, an HP 2100 IOP uses a modified BBL (Basic Binary Loader), whereas
; a 21MX IOP uses the paper tape loader ROM (12992K).  In either case, the
; loader is configured to read from the lower processor interconnect select
; code.
;
; In simulation, we use the IPL device loader, which automatically uses the
; correct loader for the current CPU model.  This permits changing the CPU model
; without having to redo this section.

deposit S 000000
load IPL

step 20


; Signal the SP that we are ready to load the IOP program.

echo
echo Signalling the SP that that the IOP is ready to receive its program.

set IPL SIGNAL


; Continue cross-loader execution.

echo
echo Receiving the IOP program.

go


; Verify that we had a successful cross-load.

assert T=102077

echo
echo IOP cross-loading completed successfully.


; The IOP is now loaded.  It must now be unloaded back to the SP.  This cannot
; be done until the SP prints "START IOP AT LOCATION 2002" to indicate that it
; is ready.  If we don't wait, then the IOP-to-SP transfer will not occur
; because the SP issues a CLF to initialize the IPL just before printing the
; message.  If the IOP sets the flag before the SP clears it, the SP and IOP
; both hang while waiting for the IPL transfer.
;
; Wait for the SP to time out and halt after cross-loading completes.

echo
echo Waiting for the SP to halt after completing the cross-load...

set IPL WAIT


; The SP is now ready for us.  Start the IOP to dump memory across the IPL.
;
; Expect halt 102077 when the transfer is complete.

echo
echo Dumping the IOP program back to the SP.

deposit P 002002
go


; The IOP tape is now written.  Then the memory map is printed, and finally the
; CPU halts with 77B.
;
; The IOP also halts after the tape is written.  However, the IOP must not exit
; at that point, or the SP's IPL poll will fail.

assert T=102077

echo
echo IOP dumping completed successfully.


; Wait until the SP is done before exiting.

echo
echo Waiting for the SP to complete and halt.

set IPL WAIT


; We're done.

exit
