;                   Verify the CPU and disc model parameters.
;
;
; This include file checks that the CPU and disc models, if supplied, are legal
; and sets the CPU, DISC, SERIES, and DEVICE environment variables to the
; corresponding values.  It is invoked by the "tsb-*.sim" command files and is
; passed the first two invocation parameters as follows:
;
;    do parameters.inc [ <param-1> ] [ <param-2> ]
;
; This file is never invoked directly by the user.
;
; The parameters may appear in any order and may be defaulted.  If an invalid
; parameter is supplied, this routine prints an error message and exits the
; simulator.
;
; On return, each environment variable will have one of these values:
;
;    CPU    = 2100, 21MX, 21MX-E
;    DISC   = 7900, 7905, 7920, 2883
;    SERIES = 2100, 21MX
;    DEVICE = DPC, DQC, DS
;
; CPU and DISC are set to the specific models requested or the default values if
; omitted, while SERIES is set to the general CPU type, and DEVICE is set to
; the disc simulator device code.


; Verify the CPU and disc model parameters.
;
; The legal parameter values are:
;
;   - CPU:  2100 (default), 21MX, or 21MX-E
;   - Disc: 7900 (default), 7905, 7920, or 2883.

set env ERROR=

if "%1" != "" if "%1" != "2100" if -I "%1" != "21MX" if -I "%1" != "21MX-E" if "%1" != "7900" if "%1" != "7905" if "%1" != "7920" if "%1" != "2883" set env ERROR=Y
if "%2" != "" if "%2" != "2100" if -I "%2" != "21MX" if -I "%2" != "21MX-E" if "%2" != "7900" if "%2" != "7905" if "%2" != "7920" if "%2" != "2883" set env ERROR=Y

if "%ERROR%" != "" echo The CPU model parameter must be omitted or 2100, 21MX, or 21MX-E,
if "%ERROR%" != "" echo and the disc model parameter must be omitted or 7900, 7905, 7920, or 2883.
if "%ERROR%" != "" exit


; Process the first parameter.

set env CPU=
set env DISC=

if    "%1" == "2100"   set env CPU=2100   ; set env SERIES=2100
if -I "%1" == "21MX"   set env CPU=21MX   ; set env SERIES=21MX
if -I "%1" == "21MX-E" set env CPU=21MX-E ; set env SERIES=21MX

if    "%1" == "7900"   set env DISC=7900  ; set env DEVICE=DPC
if    "%1" == "7905"   set env DISC=7905  ; set env DEVICE=DS
if    "%1" == "7920"   set env DISC=7920  ; set env DEVICE=DS
if    "%1" == "2883"   set env DISC=2883  ; set env DEVICE=DQC


; Process the second parameter.

if    "%2" == "2100"   set env CPU=2100   ; set env SERIES=2100
if -I "%2" == "21MX"   set env CPU=21MX   ; set env SERIES=21MX
if -I "%2" == "21MX-E" set env CPU=21MX-E ; set env SERIES=21MX

if    "%2" == "7900"   set env DISC=7900  ; set env DEVICE=DPC
if    "%2" == "7905"   set env DISC=7905  ; set env DEVICE=DS
if    "%2" == "7920"   set env DISC=7920  ; set env DEVICE=DS
if    "%2" == "2883"   set env DISC=2883  ; set env DEVICE=DQC


; If neither parameter was specified, set up the defaults.

if "%CPU%"  == "" set env CPU=2100  ; set env SERIES=2100
if "%DISC%" == "" set env DISC=7900 ; set env DEVICE=DPC
